diff --git a/docs/libs/gst-plugins-base-libs-docs.sgml b/docs/libs/gst-plugins-base-libs-docs.sgml
index 65677efb94..9902258ba9 100644
--- a/docs/libs/gst-plugins-base-libs-docs.sgml
+++ b/docs/libs/gst-plugins-base-libs-docs.sgml
@@ -44,6 +44,8 @@
+
+
diff --git a/docs/libs/gst-plugins-base-libs-sections.txt b/docs/libs/gst-plugins-base-libs-sections.txt
index f19607a869..8c0a8b3f9d 100644
--- a/docs/libs/gst-plugins-base-libs-sections.txt
+++ b/docs/libs/gst-plugins-base-libs-sections.txt
@@ -124,6 +124,86 @@ GST_IS_AUDIO_CLOCK_CLASS
GST_AUDIO_CLOCK_CAST
+
+gstaudiodecoder
+gst/audio/gstaudiodecoder.h
+GstAudioDecoder
+GstAudioDecoderClass
+GST_AUDIO_DECODER_ERROR
+GST_AUDIO_DECODER_SINK_NAME
+GST_AUDIO_DECODER_SINK_PAD
+GST_AUDIO_DECODER_SRC_NAME
+GST_AUDIO_DECODER_SRC_PAD
+gst_audio_decoder_finish_frame
+gst_audio_decoder_get_audio_info
+gst_audio_decoder_get_byte_time
+gst_audio_decoder_get_delay
+gst_audio_decoder_get_latency
+gst_audio_decoder_get_max_errors
+gst_audio_decoder_get_min_latency
+gst_audio_decoder_get_parse_state
+gst_audio_decoder_get_plc
+gst_audio_decoder_get_plc_aware
+gst_audio_decoder_get_tolerance
+gst_audio_decoder_set_byte_time
+gst_audio_decoder_set_latency
+gst_audio_decoder_set_max_errors
+gst_audio_decoder_set_min_latency
+gst_audio_decoder_set_plc
+gst_audio_decoder_set_plc_aware
+gst_audio_decoder_set_tolerance
+
+GST_AUDIO_DECODER
+GST_IS_AUDI_DECODER
+GST_TYPE_AUDIO_DECODER
+gst_audio_decoder_get_type
+GST_AUDIO_DECODER_CLASS
+GST_IS_AUDIO_DECODER_CLASS
+GST_AUDIO_DECODER_GET_CLASS
+GstAudioDecoderPrivate
+
+
+
+gstaudioencoder
+gst/audio/gstaudioencoder.h
+GstAudioEncoder
+GstAudioEncoderClass
+GST_AUDIO_ENCODER_SEGMENT
+GST_AUDIO_ENCODER_SINK_NAME
+GST_AUDIO_ENCODER_SINK_PAD
+GST_AUDIO_ENCODER_SRC_NAME
+GST_AUDIO_ENCODER_SRC_PAD
+gst_audio_encoder_finish_frame
+gst_audio_encoder_get_audio_info
+gst_audio_encoder_get_frame_max
+gst_audio_encoder_get_frame_samples
+gst_audio_encoder_get_hard_resync
+gst_audio_encoder_get_latency
+gst_audio_encoder_get_lookahead
+gst_audio_encoder_get_mark_granule
+gst_audio_encoder_get_perfect_timestamp
+gst_audio_encoder_get_tolerance
+gst_audio_encoder_proxy_getcaps
+gst_audio_encoder_set_frame_max
+gst_audio_encoder_set_frame_samples
+gst_audio_encoder_set_hard_resync
+gst_audio_encoder_set_latency
+gst_audio_encoder_set_lookahead
+gst_audio_encoder_set_mark_granule
+gst_audio_encoder_set_perfect_timestamp
+gst_audio_encoder_set_tolerance
+
+GST_AUDIO_ENCODER
+GST_AUDIO_ENCODER_CAST
+GST_IS_AUDIO_ENCODER
+GST_TYPE_AUDIO_ENCODER
+gst_audio_encoder_get_type
+GST_AUDIO_ENCODER_CLASS
+GST_IS_AUDIO_ENCODER_CLASS
+GST_AUDIO_ENCODER_GET_CLASS
+GstAudioEncoderPrivate
+
+
gstaudiofilter
gst/audio/gstaudiofilter.h
diff --git a/docs/libs/gst-plugins-base-libs.types b/docs/libs/gst-plugins-base-libs.types
index f6c06af2cd..991a97579e 100644
--- a/docs/libs/gst-plugins-base-libs.types
+++ b/docs/libs/gst-plugins-base-libs.types
@@ -3,6 +3,10 @@
#include
gst_audio_clock_get_type
+#include
+gst_audio_decoder_get_type
+#include
+gst_audio_encoder_get_type
#include
gst_audio_filter_get_type
#include
diff --git a/gst-libs/gst/audio/gstaudiodecoder.c b/gst-libs/gst/audio/gstaudiodecoder.c
index 087baac1f1..24298ec000 100644
--- a/gst-libs/gst/audio/gstaudiodecoder.c
+++ b/gst-libs/gst/audio/gstaudiodecoder.c
@@ -2116,10 +2116,11 @@ gst_audio_decoder_set_latency (GstAudioDecoder * dec,
/**
* gst_audio_decoder_get_latency:
* @dec: a #GstAudioDecoder
- * @min: a pointer to storage to hold minimum latency
- * @max: a pointer to storage to hold maximum latency
+ * @min: (out) (allow-none): a pointer to storage to hold minimum latency
+ * @max: (out) (allow-none): a pointer to storage to hold maximum latency
*
- * Returns currently configured latency.
+ * Sets the variables pointed to by @min and @max to the currently configured
+ * latency.
*
* Since: 0.10.36
*/
diff --git a/gst-libs/gst/audio/gstaudioencoder.h b/gst-libs/gst/audio/gstaudioencoder.h
index ada952fa7a..8eb9f876b4 100644
--- a/gst-libs/gst/audio/gstaudioencoder.h
+++ b/gst-libs/gst/audio/gstaudioencoder.h
@@ -128,10 +128,9 @@ struct _GstAudioEncoder {
* @set_format: Notifies subclass of incoming data format.
* GstAudioInfo contains the format according to provided caps.
* @handle_frame: Provides input samples (or NULL to clear any remaining data)
- * according to directions as provided by subclass in the
- * #GstAudioEncoderContext. Input data ref management
- * is performed by base class, subclass should not care or
- * intervene.
+ * according to directions as configured by the subclass
+ * using the API. Input data ref management is performed
+ * by base class, subclass should not care or intervene.
* @flush: Optional.
* Instructs subclass to clear any codec caches and discard
* any pending samples and not yet returned encoded data.
diff --git a/gst-libs/gst/audio/gstaudioencoder.c b/gst-libs/gst/audio/gstaudioencoder.c
index 6f47f6b732..619ec5a7ef 100644
--- a/gst-libs/gst/audio/gstaudioencoder.c
+++ b/gst-libs/gst/audio/gstaudioencoder.c
@@ -101,18 +101,18 @@
*
* In particular, base class will either favor tracking upstream timestamps
* (at the possible expense of jitter) or aim to arrange for a perfect stream of
* output timestamps, depending on #GstAudioEncoder:perfect-ts.
* However, in the latter case, the input may not be so perfect or ideal, which
* is handled as follows. An input timestamp is compared with the expected
* timestamp as dictated by input sample stream and if the deviation is less
* than #GstAudioEncoder:tolerance, the deviation is discarded.
* Otherwise, it is considered a discontuinity and subsequent output timestamp
* is resynced to the new position after performing configured discontinuity
* processing. In the non-perfect-ts case, an upstream variation exceeding
* tolerance only leads to marking DISCONT on subsequent outgoing
* (while timestamps are adjusted to upstream regardless of variation).
* While DISCONT is also marked in the perfect-ts case, this one optionally
* (see #GstAudioEncoder:hard-resync)
* performs some additional steps, such as clipping of (early) input samples
* or draining all currently remaining input data, depending on the direction
* of the discontuinity.
@@ -325,7 +325,7 @@ gst_audio_encoder_class_init (GstAudioEncoderClass * klass)
DEFAULT_PERFECT_TS, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
g_object_class_install_property (gobject_class, PROP_GRANULE,
g_param_spec_boolean ("mark-granule", "Granule Marking",
- "Apply granule semantics to buffer metadata (implies perfect-ts)",
+ "Apply granule semantics to buffer metadata (implies perfect-timestamp)",
DEFAULT_GRANULE, G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
g_object_class_install_property (gobject_class, PROP_HARD_RESYNC,
g_param_spec_boolean ("hard-resync", "Hard Resync",
@@ -1470,7 +1470,8 @@ gst_audio_encoder_set_property (GObject * object, guint prop_id,
switch (prop_id) {
case PROP_PERFECT_TS:
if (enc->priv->granule && !g_value_get_boolean (value))
- GST_WARNING_OBJECT (enc, "perfect-ts can not be set FALSE");
+ GST_WARNING_OBJECT (enc, "perfect-timestamp can not be set FALSE "
+ "while granule handling is enabled");
else
enc->priv->perfect_ts = g_value_get_boolean (value);
break;
@@ -1705,10 +1706,11 @@ gst_audio_encoder_set_latency (GstAudioEncoder * enc,
/**
* gst_audio_encoder_get_latency:
* @enc: a #GstAudioEncoder
- * @min: a pointer to storage to hold minimum latency
- * @max: a pointer to storage to hold maximum latency
+ * @min: (out) (allow-none): a pointer to storage to hold minimum latency
+ * @max: (out) (allow-none): a pointer to storage to hold maximum latency
*
- * Returns currently configured latency.
+ * Sets the variables pointed to by @min and @max to the currently configured
+ * latency.
*
* Since: 0.10.36
*/
@@ -101,18 +101,18 @@
* In particular, base class will either favor tracking upstream timestamps
* (at the possible expense of jitter) or aim to arrange for a perfect stream of
- * output timestamps, depending on #GstAudioEncoder:perfect-ts.
+ * output timestamps, depending on #GstAudioEncoder:perfect-timestamp.
* However, in the latter case, the input may not be so perfect or ideal, which
* is handled as follows. An input timestamp is compared with the expected
@@ -101,18 +101,18 @@
* Otherwise, it is considered a discontuinity and subsequent output timestamp
* is resynced to the new position after performing configured discontinuity
- * processing. In the non-perfect-ts case, an upstream variation exceeding
- * tolerance only leads to marking DISCONT on subsequent outgoing
+ * processing. In the non-perfect-timestamp case, an upstream variation
+ * exceeding tolerance only leads to marking DISCONT on subsequent outgoing
* (while timestamps are adjusted to upstream regardless of variation).
@@ -101,18 +101,18 @@
* (while timestamps are adjusted to upstream regardless of variation).
- * While DISCONT is also marked in the perfect-ts case, this one optionally
- * (see #GstAudioEncoder:hard-resync)
+ * While DISCONT is also marked in the perfect-timestamp case, this one
+ * optionally (see #GstAudioEncoder:hard-resync)
* performs some additional steps, such as clipping of (early) input samples
* or draining all currently remaining input data, depending on the direction